@@ -14,7 +14,7 @@ join (select ARTICLE_ATRIBUT_ID, SUM(QUANTITAT_TOTAL) STOCK
        GROUP BY ARTICLE_ATRIBUT_ID 
        HAVING SUM(QUANTITAT_TOTAL) > 0
 ) ps on pa.ID = ps.ARTICLE_ATRIBUT_ID
-where p.ID not in (1268, 2127, 4607) and pl.CONTROL_ESTOCS = 'S';
+where p.ID not in (1268, 2127) and pl.CONTROL_ESTOCS = 'S';
 """
 
 sync_clients = """
@@ -37,7 +37,7 @@ select
     c.NUMERO_COMANDA,
     cd.TERCER_ID CLIENT_ID,
     cd.REPARTIDOR_ID,
-    CASE WHEN c_cli.COMANDA_ID IS NULL THEN cd_ter.NOM_LLARG ELSE c_cli.TERCER END NOM_CLIENT,
+    CASE WHEN c_cli.COMANDA_ID IS NULL THEN cd_ter.NOM_LLARG_I_COMERCIAL ELSE c_cli.TERCER END NOM_CLIENT,
     CASE WHEN c_cli.COMANDA_ID IS NULL THEN cd_carrer.CARRER ELSE c_cli.ADRECA END ADRECA,
     CASE WHEN c_cli.COMANDA_ID IS NULL THEN cd_adr.CPOSTAL ELSE c_cli.CPOSTAL END CPOSTAL,
     CASE WHEN c_cli.COMANDA_ID IS NULL THEN cd_poble.POBLE ELSE c_cli_poble.POBLE END POBLE,
@@ -66,7 +66,7 @@ where c.ID = ?
 """
 
 sync_comanda_linies = """
-select cl_atr.ID ATRIBUT_ID, sum(cl.QUANTITAT) QUANTITAT, min(cl.NUMERO_LINIA) nl, cl.DESCRIPCIO, 
+select cl_atr.ID ATRIBUT_ID, sum(cl.QUANTITAT) QUANTITAT, min(cl.NUMERO_LINIA) nl, min(cl.DESCRIPCIO), 
 sum(cl.QUANTITAT) QUANTITAT_PENDENT
 from comandes c
 join comandes_linies cl on c.ID = cl.COMANDA_ID
@@ -74,7 +74,7 @@ join articles_atributs cl_atr on cl.ARTICLE_ATRIBUT_ID = cl_atr.ID
 join articles cl_art on cl_atr.ARTICLE_ID = cl_art.ID
 LEFT join select_articles_c_estocs(cl_art.ID, c.DATA_COMANDA) cl_art_stk on cl_art.ID =  cl_art_stk.ARTICLE_ID
 where cl_art_stk.CONTROL_ESTOCS = 'S' and c.ID = ?
-group by ATRIBUT_ID, cl.DESCRIPCIO  
+group by ATRIBUT_ID
 HAVING sum(cl.QUANTITAT) > 0
 """
 
